package com.mortals.xhx.module.record.service.impl;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.common.code.CertificateStatus;
import com.mortals.xhx.common.code.ClassifyType;
import com.mortals.xhx.common.code.PrintStatus;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.model.CertificateClassifyEntity;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.certificate.service.CertificateClassifyService;
import com.mortals.xhx.module.record.model.ApplyLogEntity;
import com.mortals.xhx.module.record.model.ApplyLogQuery;
import com.mortals.xhx.module.record.model.PrintLogQuery;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.record.dao.PrintLogDao;
import com.mortals.xhx.module.record.model.PrintLogEntity;
import com.mortals.xhx.module.record.service.PrintLogService;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
* PrintLogService
* 证照打印记录 service实现
*
* @author zxfei
* @date 2022-10-14
*/
@Service("printLogService")
public class PrintLogServiceImpl extends AbstractCRUDServiceImpl<PrintLogDao, PrintLogEntity, Long> implements PrintLogService {

    @Autowired
    private CertificateCatalogService certificateCatalogService;
    @Autowired
    private CertificateClassifyService certificateClassifyService;

    @Override
    protected PrintLogEntity findBefore(PrintLogEntity entity, PageInfo pageInfo, Context context) throws AppException {
        PrintLogQuery query = new PrintLogQuery();
        BeanUtils.copyProperties(entity,query);
        if(StringUtils.isNotEmpty(entity.getQuery())){
            StringBuffer condition = new StringBuffer("%");
            condition.append(entity.getQuery()).append("%");
            PrintLogQuery condition1 = new PrintLogQuery();
            PrintLogQuery condition2 = new PrintLogQuery();
            condition1.setEnterpriseName(condition.toString());
            condition2.setPickerName(condition.toString());
            List<PrintLogQuery> orConditionList = new ArrayList<>();
            orConditionList.add(condition1);
            orConditionList.add(condition2);
            query.setOrConditionList(orConditionList);
        }
        return query;
    }

    @Override
    public void creatPrintLog(ApplyLogEntity applyLogEntity, Context context) throws AppException {
        PrintLogEntity printLogEntity = new PrintLogEntity();
        printLogEntity.setCatalogId(applyLogEntity.getCatalogId());
        CertificateCatalogEntity catalogEntity = certificateCatalogService.get(applyLogEntity.getCatalogId());
        CertificateClassifyEntity classifyEntity = certificateClassifyService.get(catalogEntity.getClassifyId());
        printLogEntity.setCatalogCode(catalogEntity.getCatalogCode());
        if(classifyEntity.getClassifyType()== ClassifyType.PRINCIPAL.getValue()){
            printLogEntity.setOriginalCount(1);
            printLogEntity.setDuplicateCount(0);
        }
        if(classifyEntity.getClassifyType()== ClassifyType.PRINCIPAL_AND_VICE.getValue()){
            printLogEntity.setOriginalCount(1);
            printLogEntity.setDuplicateCount(1);
        }
        printLogEntity.setCertificateName(applyLogEntity.getCertificateName());
        printLogEntity.setCertificateCode(applyLogEntity.getCertificateCode());
        printLogEntity.setEnterpriseName(applyLogEntity.getEnterpriseName());
        printLogEntity.setHolderName(applyLogEntity.getHolderName());
        printLogEntity.setHolderIDCardNo(applyLogEntity.getHolderIDCardNo());
        printLogEntity.setPrintStatus(PrintStatus.SUCCESS.getValue());
        Date now = new Date();
        printLogEntity.setPrintDate(now);
        printLogEntity.setCreateUserId(applyLogEntity.getCreateUserId());
        printLogEntity.setCreateTime(now);

        dao.insert(printLogEntity);
    }
}